Narratives and Use Cases
========================

.. toctree::
   :maxdepth: 2

   narrative-notebook
   narrative-hub
   narrative-other
   data_science
   science
   education
   enterprise

What are Narratives?
--------------------
Narratives are *collaborative*, *shareable*, *publishable*, and
*reproducible*. We believe that Narratives help both yourself and other
researchers by sharing your use of Jupyter projects, technical specifics of
your deployment, and installation and configuration tips so that others can
learn from your experiences.
